==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/es-VE/admin/kits/general.php <==
<?php

return [
    'about_kits_title'                  => 'Acerca de Kits predefinidos',
    'about_kits_text'                   => 'Kits predefinidos le permiten revisar rápidamente una colección de elementos (activos, licencias, etc.) a un usuario. Esto puede ser útil cuando su proceso de incorporación es consistente entre muchos usuarios y todos los usuarios reciben los mismos artículos.',
    'checkout'                          => 'Kit de pago ',
    'create_success'                    => 'El kit se ha creado correctamente.',
    'create'                            => 'Crear kit predefinido',
    'update'                            => 'Actualizar kit predefinido',
    'delete_success'                    => 'Kit eliminado correctamente.',
    'update_success'                    => 'El kit se ha actualizado correctamente.',
    'none_models'                       => 'No hay suficientes recursos disponibles para :model para pagar. :qty son requeridos. ',
    'none_licenses'                     => 'No hay suficientes asientos disponibles para :license para pagar. :qty son requeridos. ',
    'none_consumables'                  => 'No hay suficientes unidades disponibles de :consumible para pagar. :qty son requeridas. ',
    'none_accessory'                    => 'No hay suficientes unidades disponibles de :accesory para pagar. :qty son requeridas. ',
    'append_accessory'                  => 'Añadir accesorio',
    'update_appended_accessory'         => 'Actualizar accesorio adjunto',
    'append_consumable'                 => 'Añadir consumible',
    'update_appended_consumable'        => 'Actualizar consumible adjunto',
    'append_license'                    => 'Añadir licencia',
    'update_appended_license'           => 'Actualizar licencia añadida',
    'append_model'                      => 'Añadir modelo',
    'update_appended_model'             => 'Actualizar modelo añadido',
    'license_error'                     => 'Licencia ya adjunta al kit',
    'license_added_success'             => 'Licencia creada con éxito',
    'license_updated'                   => 'La licencia se ha actualizado correctamente',
    'license_none'                      => 'La licencia no existe',
    'license_detached'                  => 'Licencia fue separada con éxito',
    'consumable_added_success'          => 'Consumible creado con éxito',
    'consumable_updated'                => 'Consumible se ha actualizado correctamente',
    'consumable_error'                  => 'Consumible ya conectado al kit',
    'consumable_deleted'                => 'El borrado fue exitoso',
    'consumable_none'                   => 'El consumible no existe',
    'consumable_detached'               => 'Consumible fue separado con éxito',
    'accessory_added_success'           => 'Accesorio añadido correctamente',
    'accessory_updated'                 => 'El accesorio se ha actualizado correctamente',
    'accessory_detached'                => 'Accesorio fue separado con éxito',
    'accessory_error'                   => 'El accesorio ya está conectado al kit',
    'accessory_deleted'                 => 'El borrado fue exitoso',
    'accessory_none'                    => 'El accesorio no existe',
    'checkout_success'                  => 'El pago fue exitoso',
    'checkout_error'                    => 'Error de pago',
    'kit_none'                          => 'El kit no existe',
    'kit_created'                       => 'El kit se creó con éxito',
    'kit_updated'                       => 'El kit se actualizó con éxito',
    'kit_not_found'                     => 'Kit no encontrado',
    'kit_deleted'                       => 'Kit eliminado correctamente',
    'kit_model_updated'                 => 'El modelo se ha actualizado correctamente',
    'kit_model_detached'                => 'Modelo fue separado con éxito',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/es-VE/admin/kits/general.php <==
<?php

return [
    'about_kits_title'                  => 'Acerca de Kits predefinidos',
    'about_kits_text'                   => 'Los kits predefinidos le permiten rápidamente asignar un conjunto de elementos (activos, licencias, etc.) a un usuario. Esto puede ser útil cuando su proceso de incorporación de usuarios es similar para muchos usuarios y todos reciben los mismos elementos.',
    'checkout'                          => 'Asignar kit ',
    'create_success'                    => 'El kit se ha creado correctamente.',
    'create'                            => 'Crear kit predefinido',
    'update'                            => 'Actualizar kit predefinido',
    'delete_success'                    => 'Kit eliminado correctamente.',
    'update_success'                    => 'El kit se ha actualizado correctamente.',
    'none_models'                       => 'No hay suficientes activos disponibles de :model para asignar. Se requieren :qty. ',
    'none_licenses'                     => 'No hay suficientes licencias disponibles de :license para asignar. Se requieren :qty. ',
    'none_consumables'                  => 'No hay suficientes unidades disponibles de :consumable para asignar. Se requieren :qty. ',
    'none_accessory'                    => 'No hay suficientes unidades disponibles de :accessory para asignar. Se requieren :qty. ',
    'append_accessory'                  => 'Añadir accesorio',
    'update_appended_accessory'         => 'Actualizar accesorio añadido',
    'append_consumable'                 => 'Añadir consumible',
    'update_appended_consumable'        => 'Actualizar consumible adjunto',
    'append_license'                    => 'Añadir licencia',
    'update_appended_license'           => 'Actualizar licencia añadida',
    'append_model'                      => 'Añadir modelo',
    'update_appended_model'             => 'Actualizar modelo añadido',
    'license_error'                     => 'Licencia ya adjunta al kit',
    'license_added_success'             => 'Licencia creada con éxito',
    'license_updated'                   => 'La licencia se ha actualizado correctamente',
    'license_none'                      => 'La licencia no existe',
    'license_detached'                  => 'Licencia fue separada con éxito',
    'consumable_added_success'          => 'Consumible creado con éxito',
    'consumable_updated'                => 'Consumible se ha actualizado correctamente',
    'consumable_error'                  => 'Consumible ya conectado al kit',
    'consumable_deleted'                => 'El borrado fue exitoso',
    'consumable_none'                   => 'El consumible no existe',
    'consumable_detached'               => 'Consumible fue separado con éxito',
    'accessory_added_success'           => 'Accesorio añadido correctamente',
    'accessory_updated'                 => 'El accesorio se ha actualizado correctamente',
    'accessory_detached'                => 'Accesorio fue separado con éxito',
    'accessory_error'                   => 'El accesorio ya está conectado al kit',
    'accessory_deleted'                 => 'El borrado fue exitoso',
    'accessory_none'                    => 'El accesorio no existe',
    'checkout_success'                  => 'Asignación correcta',
    'checkout_error'                    => 'Error al asignar',
    'kit_none'                          => 'El kit no existe',
    'kit_created'                       => 'El kit se creó con éxito',
    'kit_updated'                       => 'El kit se actualizó con éxito',
    'kit_not_found'                     => 'Kit no encontrado',
    'kit_deleted'                       => 'Kit eliminado correctamente',
    'kit_model_updated'                 => 'El modelo se ha actualizado correctamente',
    'kit_model_detached'                => 'Modelo fue separado con éxito',
];
